Overview
--------

This project aims to provide Python bindings to interact with the `SEAScope`_
application developed by `OceanDataLab`_.

These bindings allow users to control the application remotely and to transfer
data between Python and SEAScope. These features can be used to create scripted
animations (e.g. to illustrate a study during a conference) or to analyse and
visualise data interactively.

See the `API documentation`_ for more information

.. _SEAScope: https://seascope.oceandatalab.com
.. _OceanDataLab: https://www.oceandatalab.com
.. _API documentation: https://seascope.oceandatalab.com/python_api/index.html

